==> dde-calendar_5.9.5.orig.tar.xz: dde-calendar-5.9.5/translations/dde-calendar-service_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Работа</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Жизнь</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Остальное</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>За день до начала</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Напомнить завтра</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Напомнить позже</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>Спустя 15 минут</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>Спустя 1 час</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>Спустя 4 часа</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Завтра</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Напоминание о расписании</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>от 1% до %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Сегодня</translation>
    </message>
</context>
<context>
    <name>JobRemindManager</name>
    <message>
        <source>One day before start</source>
        <translation type="vanished">За день до начала</translation>
    </message>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">Закрыть</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">Напомни мне завтра</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">Напомни мне позже</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">Напоминание о расписании</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">от 1% до %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">Сегодня</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">Завтра</translation>
    </message>
</context>
</TS>

==> dde-calendar_5.9.14.orig.tar.xz: dde-calendar-5.9.14/translations/dde-calendar-service_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Работа</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Жизнь</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Остальное</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>За день до начала</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Напомнить завтра</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Напомнить позже</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>Спустя 15 минут</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>Спустя 1 час</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>Спустя 4 часа</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Завтра</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Напоминание о расписании</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>от 1% до %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Сегодня</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
